/**
 * Deploy GitHub pages, using git subtree commands.
 * @memberof apeman-dev-commons-deploying/lib
 * @function deployGhPages
 * @param {string} dirname - Dirname to deploy.
 * @param {object} [options] - Optional settings.
 * @param {string} [options.remote='origin'] - Remote repo name.
 * @param {function} [callback] - Callback when done.
 */

"use strict";

var apeDeploying = require('ape-deploying'),
    argx= require('argx'),
    async = require('async'),
    colorprint = require('colorprint');

/** @lends deployGhPages */
function deployGhPages(dirname, options, callback) {
    var args = argx(arguments);
    dirname = args.shift();
    callback = args.pop('function');
    options  = args.pop('object') || {};
    async.series([
        function (callback) {
            colorprint.info('Deploying GitHub Pages started...');
            callback(null);
        },
        function (callback) {
            apeDeploying.deployGhPages(dirname, options, callback);
        },
        function (callback) {
            colorprint.info('...deploying GitHub Pages done!');
            callback(null);
        }
    ], callback);
}

module.exports = deployGhPages;